function StockSymbol(){
	this.symbol = "";
	this.name = "";
	this.trade = "";
	this.change = "";
	this.changePercent = "";
	this.prevClose = "";
	this.open = "";
	this.dayLow = "";
	this.dayHigh = "";
	this.yearLow = "";
	this.yearHigh = "";
	this.ebitda = "";
	
	this.portfolio 		= 0;
	this.strike 		= 0;
	this.shares 		= 0;
	
	this.format 		= null;
	this.url			= null;
	this.lastupdate 	= 0;
	
	/**
	* Get details site url for this stock
	* @return string url
	*/
	this.getUrl = function(){
	
		// Get URL
		var url		= "http://finance.yahoo.com/q?s=$";
		var oPref	= Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);
		if(this.url != null){
			url = this.url;
		}
		else if(oPref.prefHasUserValue("stockticker.details.site")){
			url = oPref.getCharPref("stockticker.details.site");
		}
		
		// Add symbol
		url = url.replace(/\$/g, this.symbol);
		
		return url;
	}
	
	/**
	* Convert the stock symbol information to string 
	*
	* Formatted by code stored in preference stockticker.display.string
	* @return string
	*/
	this.toString = function(){
		try{
			var values = new Array();
				values["sym"]		= this.symbol,
				values["name"]		= this.name,
				values["\\$"]		= this.trade,
				values["\\$\\$"]	= this.portfolio,
				values["ch"]		= this.change,
				values["ch%"]		= this.changePercent,
				values["pcls"]		= this.prevClose,
				values["open"]		= this.open,
				values["dlow"]		= this.dayLow,
				values["dhigh"]		= this.dayHigh,
				values["ylow"]		= this.yearLow,
				values["yhigh"]		= this.yearHigh,
				values["ebitda"]	= this.ebitda
				
			// Get Format		
			var oPref	= Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);
			var format	= "[name] [$] ([ch] / [ch%]%)";
			if(this.format != null){
				format = this.format;
			}
			else if(oPref.prefHasUserValue("stockticker.display.format")){
				format = oPref.getCharPref("stockticker.display.format");
			}
		
			for(key in values){
				if(!isNaN(values[key])){
					values[key] = this.formatNumber(values[key]);
				}
				
				if(key == "ch" && parseInt(values[key]) > 0){
					values[key] = "+"+ values[key];
				}
			
				format = format.replace(new RegExp("\\["+ key +"\\]", "g"), values[key]);
			}
			
			return format;
			
		}catch(e){
			throw "StockSymbol(getDisplay)\n"+ e;
		}
	}
	
	/**
	* Format number string
	*
	* Will format a number with a comma for every hundred
	* @param {string} str String with numbers to parse
	* @return string
	*/
	this.formatNumber = function(str){
		var out = "";
	
		// Decimal
		str = parseFloat(str).toFixed(2) +"";
		
		// Thousands
		var count = 0;
		out = str.substring(str.length - 3);
		for(var i = str.length - 4; i > -1; i--){
			if(count == 3 && !isNaN(str.charAt(i))){
				count = 0;
				out = str.charAt(i) + "," + out;
			}
			else{
				count++;
				out = str.charAt(i) + out;
			}
		}
		
		return out;
	}
	
	/**
	* Output's debug statments
	* @param {string}msg Debug message
	*/
	this.debug = function(msg){
		return;
	
		if(typeof(Components.classes["@mozmonkey.com/debuglogger/manager;1"]) != 'undefined'){
			var logMngr = Components.classes["@mozmonkey.com/debuglogger/manager;1"].getService(Components.interfaces.nsIDebugLoggerManager);
			logMngr.registerLogger("stockticker").log(3, msg);
		}
	}
}

StockSymbol.prototype = {
	QueryInterface: function (iid) {
		if(!iid.equals(Components.interfaces.nsIStockSymbol) && !iid.equals(Components.interfaces.nsISupports))
			throw Components.results.NS_ERROR_NO_INTERFACE;
		
		return this;
	}
};
var Module = {
	myCID : Components.ID("{9230FBA3-5B3F-4473-B4D0-4A12DB054BD2}"),
    myProgID : "@mozmonkey.com/stockticker/symbol;1",
    firstTime : true,
	registerSelf : function (compMgr, fileSpec, location, type) {
		if(this.firstTime) {
			this.firstTime = false;
			throw Components.results.NS_ERROR_FACTORY_REGISTER_AGAIN;
		}
		compMgr = compMgr.QueryInterface(Components.interfaces.nsIComponentRegistrar);
		compMgr.registerFactoryLocation(this.myCID, "StockTicker Symbol", this.myProgID, fileSpec, location, type);
	},
	getClassObject : function (compMgr, cid, iid) {
		if (!cid.equals(this.myCID)) throw Components.results.NS_ERROR_NO_INTERFACE;
		if (!iid.equals(Components.interfaces.nsIFactory)) throw Components.results.NS_ERROR_NOT_IMPLEMENTED;
		return this.myFactory;
	},
    myFactory : {
		createInstance : function (outer, iid) {
			if (outer != null) throw Components.results.NS_ERROR_NO_AGGREGATION;
			return (new StockSymbol()).QueryInterface(iid);
		}
	},
    canUnload : function(compMgr) { return true; }
};
function NSGetModule(compMgr, fileSpec) { return Module; }